@@ -19,7 +19,7 @@ an ACATS Transfer
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
 use Time::Moment;
@@ -28,8 +28,9 @@ sub _test__init {
     my $rh       = t::Utility::rh_instance(1);
     my $transfer = $rh->acats_transfers->current;
     skip_all('No ACATS transfers found') if !defined $transfer;
-    isa_ok( $transfer->equity_positions->[0], __PACKAGE__ );
-    t::Utility::stash( 'POSITION', $transfer->equity_positions->[0] );    #  Store it for later
+    isa_ok($transfer->equity_positions->[0], __PACKAGE__);
+    t::Utility::stash('POSITION', $transfer->equity_positions->[0])
+        ;    #  Store it for later
 }
 #
 has _rh => undef => weak => 1;
@@ -47,7 +48,7 @@ Number of shares in this position
 
 =cut
 
-has [ 'price', 'quantity' ];
+has ['price', 'quantity'];
 
 =head2 C<instrument( )>
 
@@ -58,16 +59,18 @@ Loops back to a Finance::Robinhood::Equity::Instrument object.
 =cut
 
 sub instrument ($s) {
-    my $res = $s->_rh->_get( $s->{instrument} );
+    my $res = $s->_rh->_get($s->{instrument});
     $res->is_success
-        ? Finance::Robinhood::Equity::Instrument->new( _rh => $s->_rh, %{ $res->json } )
+        ? Finance::Robinhood::Equity::Instrument->new(_rh => $s->_rh,
+                                                      %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_instrument {
     t::Utility::stash('POSITION') // skip_all();
-    isa_ok( t::Utility::stash('POSITION')->instrument, 'Finance::Robinhood::Equity::Instrument' );
+    isa_ok(t::Utility::stash('POSITION')->instrument,
+           'Finance::Robinhood::Equity::Instrument');
 }
 
 =head1 LEGAL
