@@ -14,30 +14,31 @@ Finance::Robinhood::Equity::Account - Represents a Single Robinhood Account
     my $rh = Finance::Robinhood->new->login('user', 'pass');
     my $account = $rh->equity_accounts->current();
 
-    CORE::say sprintf '$%0.2f of $%0.2f can be withdrawn', 
+    CORE::say sprintf '$%0.2f of $%0.2f can be withdrawn',
         $account->cash_available_for_withdrawal,
         $account->cash;
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 
 sub _test__init {
     my $rh   = t::Utility::rh_instance(1);
     my $acct = $rh->equity_accounts->current;
-    isa_ok( $acct, __PACKAGE__ );
-    t::Utility::stash( 'ACCT', $acct );    #  Store it for later
+    isa_ok($acct, __PACKAGE__);
+    t::Utility::stash('ACCT', $acct);    #  Store it for later
 }
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
-use overload '""' => sub ( $s, @ ) { $s->{url} }, fallback => 1;
+use overload '""' => sub ($s, @) { $s->{url} }, fallback => 1;
 use Finance::Robinhood::Equity::Account::Portfolio;
 use Finance::Robinhood::Equity::Account::InstantEligibility;
 use Finance::Robinhood::Equity::Account::MarginBalances;
 
 sub _test_stringify {
     t::Utility::stash('ACCT') // skip_all();
-    like( +t::Utility::stash('ACCT'), qr'https://api.robinhood.com/accounts/.+/' );
+    like(+t::Utility::stash('ACCT'),
+         qr'https://api.robinhood.com/accounts/.+/');
 }
 ##
 
@@ -103,8 +104,8 @@ One of several options:
 =item * C<option_level_3>
 
 =back
-     
-=head2 C<rhs_account_number( )>          
+
+=head2 C<rhs_account_number( )>
 
 Internal account number used for official documents (tax forms, etc.)
 
@@ -112,11 +113,11 @@ Internal account number used for official documents (tax forms, etc.)
 
 TODO
 
-=head2 C<sma_held_for_orders( )>          
+=head2 C<sma_held_for_orders( )>
 
 TODO
 
-=head2 C<sweep_enabled( )>          
+=head2 C<sweep_enabled( )>
 
 Returns true if sweep is enabled to move cash between your brokerage account to
 RH's crypto service.
@@ -125,15 +126,15 @@ RH's crypto service.
 
 Simple C<cash> or C<margin> account flag.
 
-=head2 C<uncleared_deposits( )>          
+=head2 C<uncleared_deposits( )>
 
 Incoming ACH deposits that have not cleared yet.
 
-=head2 C<unsettled_debit( )>          
+=head2 C<unsettled_debit( )>
 
 Outgoing funds that are not yet settled.
 
-=head2 C<unsettled_funds( )>          
+=head2 C<unsettled_funds( )>
 
 Funds that are not yet settled but may be used thanks to Gold or Instant margin
 accounts.
@@ -144,18 +145,17 @@ True if the account has been flagged and ACH withdrawal has been disabled.
 
 =cut
 
-has [
-    'account_number',              'cash',
-    'buying_power',                'cash_available_for_withdrawal',
-    'cash_held_for_orders',        'deactivated',
-    'deposit_halted',              'is_pinnacle_account',
-    'max_ach_early_access_amount', 'only_position_closing_trades',
-    'option_level',                'rhs_account_number',
-    'sma',                         'sma_held_for_orders',
-    'sweep_enabled',               'type',
-    'uncleared_deposits',          'unsettled_debit',
-    'unsettled_funds',             'url',
-    'withdrawal_halted'
+has ['account_number',              'cash',
+     'buying_power',                'cash_available_for_withdrawal',
+     'cash_held_for_orders',        'deactivated',
+     'deposit_halted',              'is_pinnacle_account',
+     'max_ach_early_access_amount', 'only_position_closing_trades',
+     'option_level',                'rhs_account_number',
+     'sma',                         'sma_held_for_orders',
+     'sweep_enabled',               'type',
+     'uncleared_deposits',          'unsettled_debit',
+     'unsettled_funds',             'url',
+     'withdrawal_halted'
 ];
 
 =head2 C<created_at( )>
@@ -165,12 +165,12 @@ Returns a Time::Moment object.
 =cut
 
 sub created_at ($s) {
-    Time::Moment->from_string( $s->{created_at} );
+    Time::Moment->from_string($s->{created_at});
 }
 
 sub _test_created_at {
     t::Utility::stash('ACCT') // skip_all('No account object in stash');
-    isa_ok( t::Utility::stash('ACCT')->created_at, 'Time::Moment' );
+    isa_ok(t::Utility::stash('ACCT')->created_at, 'Time::Moment');
 }
 
 =head2 C<updated_at( )>
@@ -180,12 +180,12 @@ Returns a Time::Moment object.
 =cut
 
 sub updated_at ($s) {
-    Time::Moment->from_string( $s->{updated_at} );
+    Time::Moment->from_string($s->{updated_at});
 }
 
 sub _test_updated_at {
     t::Utility::stash('ACCT') // skip_all('No account object in stash');
-    isa_ok( t::Utility::stash('ACCT')->updated_at, 'Time::Moment' );
+    isa_ok(t::Utility::stash('ACCT')->updated_at, 'Time::Moment');
 }
 
 =head2 C<user( )>
@@ -195,17 +195,17 @@ Returns the related Finance::Robinhood::Equity::Account object.
 =cut
 
 sub user ($s) {
-    my $res = $s->_rh->_get( $s->{user} );
+    my $res = $s->_rh->_get($s->{user});
     require Finance::Robinhood::User;
     $res->is_success
-        ? Finance::Robinhood::User->new( _rh => $s->_rh, %{ $res->json } )
+        ? Finance::Robinhood::User->new(_rh => $s->_rh, %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_user {
     t::Utility::stash('ACCT') // skip_all('No account object in stash');
-    isa_ok( t::Utility::stash('ACCT')->user, 'Finance::Robinhood::User' );
+    isa_ok(t::Utility::stash('ACCT')->user, 'Finance::Robinhood::User');
 }
 
 =head2 C<can_downgrade_to_cash( )>
@@ -216,17 +216,18 @@ downgrading from a margin account (Instant or Gold) to a cash account.
 =cut
 
 sub can_downgrade_to_cash ($s) {
-    my $res = $s->_rh->_get( $s->{can_downgrade_to_cash} );
+    my $res = $s->_rh->_get($s->{can_downgrade_to_cash});
     $res->is_success
         ? $res->json->{can_downgrade_to_cash}
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_can_downgrade_to_cash {
     t::Utility::stash('ACCT') // skip_all('No account object in stash');
-    my $can_downgrade_to_cash = t::Utility::stash('ACCT')->can_downgrade_to_cash;
-    isa_ok( $can_downgrade_to_cash, 'JSON::PP::Boolean' );
+    my $can_downgrade_to_cash
+        = t::Utility::stash('ACCT')->can_downgrade_to_cash;
+    isa_ok($can_downgrade_to_cash, 'JSON::PP::Boolean');
 }
 
 =head2 C<instant_eligibility( )>
@@ -238,15 +239,16 @@ object.
 
 sub instant_eligibility ($s) {
     Finance::Robinhood::Equity::Account::InstantEligibility->new(
-        _rh => $s->_rh,
-        %{ $s->{instant_eligibility} }
+                                                  _rh => $s->_rh,
+                                                  %{$s->{instant_eligibility}}
     );
 }
 
 sub _test_instant_eligibility {
     t::Utility::stash('ACCT') // skip_all('No account object in stash');
     my $instant_eligibility = t::Utility::stash('ACCT')->instant_eligibility;
-    isa_ok( $instant_eligibility, 'Finance::Robinhood::Equity::Account::InstantEligibility' );
+    isa_ok($instant_eligibility,
+           'Finance::Robinhood::Equity::Account::InstantEligibility');
 }
 
 =head2 C<margin_balances( )>
@@ -257,15 +259,16 @@ Returns the related Finance::Robinhood::Equity::Account::MarginBalances object.
 
 sub margin_balances ($s) {
     Finance::Robinhood::Equity::Account::MarginBalances->new(
-        _rh => $s->_rh,
-        %{ $s->{margin_balances} }
+                                                      _rh => $s->_rh,
+                                                      %{$s->{margin_balances}}
     );
 }
 
 sub _test_margin_balances {
     t::Utility::stash('ACCT') // skip_all('No account object in stash');
     my $margin_balances = t::Utility::stash('ACCT')->margin_balances;
-    isa_ok( $margin_balances, 'Finance::Robinhood::Equity::Account::MarginBalances' );
+    isa_ok($margin_balances,
+           'Finance::Robinhood::Equity::Account::MarginBalances');
 }
 
 =head2 C<portfolio( )>
@@ -275,17 +278,18 @@ Returns the related Finance::Robinhood::Equity::Account::Portfolio object.
 =cut
 
 sub portfolio ($s) {
-    my $res = $s->_rh->_get( $s->{portfolio} );
+    my $res = $s->_rh->_get($s->{portfolio});
     $res->is_success
-        ? Finance::Robinhood::Equity::Account::Portfolio->new( _rh => $s->_rh, %{ $res->json } )
+        ? Finance::Robinhood::Equity::Account::Portfolio->new(_rh => $s->_rh,
+                                                              %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_portfolio {
     t::Utility::stash('ACCT') // skip_all('No account object in stash');
     my $portfolio = t::Utility::stash('ACCT')->portfolio;
-    isa_ok( $portfolio, 'Finance::Robinhood::Equity::Account::Portfolio' );
+    isa_ok($portfolio, 'Finance::Robinhood::Equity::Account::Portfolio');
 }
 
 =head2 C<positions( )>
@@ -309,20 +313,21 @@ You can filter and modify the results. All options are optional.
 
 =cut
 
-sub positions ( $s, %filters ) {
-    $filters{nonzero} = !!$filters{nonzero} ? 'true' : 'false' if defined $filters{nonzero};
-    Finance::Robinhood::Utility::Iterator->new(
-        _rh        => $s->_rh,
-        _next_page => Mojo::URL->new( $s->{positions} )->query( \%filters ),
-        _class     => 'Finance::Robinhood::Equity::Position'
+sub positions ($s, %filters) {
+    $filters{nonzero} = !!$filters{nonzero} ? 'true' : 'false'
+        if defined $filters{nonzero};
+    Finance::Robinhood::Utilities::Iterator->new(
+              _rh        => $s->_rh,
+              _next_page => Mojo::URL->new($s->{positions})->query(\%filters),
+              _class     => 'Finance::Robinhood::Equity::Position'
     );
 }
 
 sub _test_positions {
     t::Utility::stash('ACCT') // skip_all('No account object in stash');
     my $positions = t::Utility::stash('ACCT')->positions;
-    isa_ok( $positions,          'Finance::Robinhood::Utility::Iterator' );
-    isa_ok( $positions->current, 'Finance::Robinhood::Equity::Position' );
+    isa_ok($positions,          'Finance::Robinhood::Utilities::Iterator');
+    isa_ok($positions->current, 'Finance::Robinhood::Equity::Position');
 }
 
 =head1 LEGAL
