@@ -27,11 +27,13 @@ Error objects stringify to the contents of C<detail( )> or 'Unknown error.'
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
-use overload 'bool' => sub ( $s, @ ) {0},
-    '""'     => sub ( $s, @ ) { $s->detail // 'Unknown error.' },
+use overload 'bool' => sub ($s, @) {0},
+    '""'            => sub ($s, @) {
+    $s->detail // 'Unknown error.';
+    },
     fallback => 1;
 #
 
@@ -45,7 +47,6 @@ service is here.
 =cut
 
 has _rh => undef => weak => 1;
-
 has ['detail'];
 
 =head1 LEGAL
