@@ -18,23 +18,22 @@ Application
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
 
 sub _test__init {
     my $rh  = t::Utility::rh_instance(1);
     my $act = $rh->forex_activations->current;
-    isa_ok( $act, __PACKAGE__ );
-    t::Utility::stash( 'ACTIVATION', $act );    #  Store it for later
+    isa_ok($act, __PACKAGE__);
+    t::Utility::stash('ACTIVATION', $act);    #  Store it for later
 }
-use overload '""' => sub ( $s, @ ) { $s->{id} }, fallback => 1;
+use overload '""' => sub ($s, @) { $s->{id} }, fallback => 1;
 
 sub _test_stringify {
     t::Utility::stash('ACTIVATION') // skip_all();
-    like(
-        +t::Utility::stash('ACTIVATION'),
-        qr'^[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$'i
+    like(+t::Utility::stash('ACTIVATION'),
+         qr'^[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}$'i
     );
 }
 #
@@ -132,9 +131,12 @@ Returns a UUID.
 
 =cut
 
-has [
-    'email', 'external_rejection_code', 'external_rejection_reason', 'external_status_code',
-    'first_name', 'id', 'last_name', 'speculative', 'state', 'type', 'user_id'
+has ['email',                     'external_rejection_code',
+     'external_rejection_reason', 'external_status_code',
+     'first_name',                'id',
+     'last_name',                 'speculative',
+     'state',                     'type',
+     'user_id'
 ];
 
 =head2 C<created_at( )>
@@ -144,12 +146,12 @@ Returns a Time::Moment object.
 =cut
 
 sub created_at ($s) {
-    Time::Moment->from_string( $s->{created_at} );
+    Time::Moment->from_string($s->{created_at});
 }
 
 sub _test_created_at {
     t::Utility::stash('ACTIVATION') // skip_all();
-    isa_ok( t::Utility::stash('ACTIVATION')->created_at, 'Time::Moment' );
+    isa_ok(t::Utility::stash('ACTIVATION')->created_at, 'Time::Moment');
 }
 
 =head2 C<updated_at( )>
@@ -159,12 +161,12 @@ Returns a Time::Moment object.
 =cut
 
 sub updated_at ($s) {
-    Time::Moment->from_string( $s->{updated_at} );
+    Time::Moment->from_string($s->{updated_at});
 }
 
 sub _test_updated_at {
     t::Utility::stash('ACTIVATION') // skip_all();
-    isa_ok( t::Utility::stash('ACTIVATION')->updated_at, 'Time::Moment' );
+    isa_ok(t::Utility::stash('ACTIVATION')->updated_at, 'Time::Moment');
 }
 
 =head1 LEGAL
