@@ -19,18 +19,16 @@ Finance::Robinhood::News - Represents a Single News Article
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 
 sub _test__init {
     my $rh   = t::Utility::rh_instance(1);
     my $msft = $rh->news('MSFT')->current;
     my $btc  = $rh->news('d674efea-e623-4396-9026-39574b92b093')->current;
-
-    isa_ok( $msft, __PACKAGE__ );
-    t::Utility::stash( 'MSFT', $msft );    #  Store it for later
-
-    isa_ok( $btc, __PACKAGE__ );
-    t::Utility::stash( 'BTC', $btc );      #  Store it for later
+    isa_ok($msft, __PACKAGE__);
+    t::Utility::stash('MSFT', $msft);    #  Store it for later
+    isa_ok($btc, __PACKAGE__);
+    t::Utility::stash('BTC', $btc);      #  Store it for later
 }
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
@@ -69,11 +67,8 @@ Returns the article's unique ID.
 
 =cut
 
-has [
-    'api_source', 'author',
-    'num_clicks',
-    'source', 'summary',
-    'title',  'uuid'
+has ['api_source', 'author', 'num_clicks', 'source',
+     'summary',    'title',  'uuid'
 ];
 
 =head2 C<preview_image_url( )>
@@ -84,14 +79,14 @@ object.
 =cut
 
 sub preview_image_url($s) {
-    $s->{preview_image_url} ? Mojo::URL->new( $s->{preview_image_url} ) : ();
+    $s->{preview_image_url} ? Mojo::URL->new($s->{preview_image_url}) : ();
 }
 
 sub _test_preview_image_url {
     t::Utility::stash('MSFT') // skip_all();
-    isa_ok( t::Utility::stash('MSFT')->preview_image_url, 'Mojo::URL' );
+    isa_ok(t::Utility::stash('MSFT')->preview_image_url, 'Mojo::URL');
     t::Utility::stash('BTC') // skip_all();
-    isa_ok( t::Utility::stash('BTC')->preview_image_url, 'Mojo::URL' );
+    isa_ok(t::Utility::stash('BTC')->preview_image_url, 'Mojo::URL');
 }
 
 =head2 C<relay_url( )>
@@ -102,14 +97,14 @@ This will register as a click and will then redirect to the article itself.
 =cut
 
 sub relay_url($s) {
-    $s->{relay_url} ? Mojo::URL->new( $s->{relay_url} ) : ();
+    $s->{relay_url} ? Mojo::URL->new($s->{relay_url}) : ();
 }
 
 sub _test_relay_url {
     t::Utility::stash('MSFT') // skip_all();
-    isa_ok( t::Utility::stash('MSFT')->relay_url, 'Mojo::URL' );
+    isa_ok(t::Utility::stash('MSFT')->relay_url, 'Mojo::URL');
     t::Utility::stash('BTC') // skip_all();
-    isa_ok( t::Utility::stash('BTC')->relay_url, 'Mojo::URL' );
+    isa_ok(t::Utility::stash('BTC')->relay_url, 'Mojo::URL');
 }
 
 =head2 C<url( )>
@@ -119,14 +114,14 @@ Mojo::URL object containing a direct link to the article.
 =cut
 
 sub url($s) {
-    $s->{url} ? Mojo::URL->new( $s->{url} ) : ();
+    $s->{url} ? Mojo::URL->new($s->{url}) : ();
 }
 
 sub _test_url {
     t::Utility::stash('MSFT') // skip_all();
-    isa_ok( t::Utility::stash('MSFT')->url, 'Mojo::URL' );
+    isa_ok(t::Utility::stash('MSFT')->url, 'Mojo::URL');
     t::Utility::stash('BTC') // skip_all();
-    isa_ok( t::Utility::stash('BTC')->url, 'Mojo::URL' );
+    isa_ok(t::Utility::stash('BTC')->url, 'Mojo::URL');
 }
 
 =head2 C<currency_id( )>
@@ -137,12 +132,13 @@ Finance::Robinhood::Forex::Currency object.
 =cut
 
 sub currency($s) {
-    $s->{currency_id} ? $s->_rh->forex_currency_by_id( $s->{currency_id} ) : ();
+    $s->{currency_id} ? $s->_rh->forex_currency_by_id($s->{currency_id}) : ();
 }
 
 sub _test_currency {
     t::Utility::stash('BTC') // skip_all();
-    isa_ok( t::Utility::stash('BTC')->currency, 'Finance::Robinhood::Forex::Currency' );
+    isa_ok(t::Utility::stash('BTC')->currency,
+           'Finance::Robinhood::Forex::Currency');
 }
 
 =head2 C<instrument( )>
@@ -154,14 +150,16 @@ Finance::Robihood::Equity::Instrument object.
 
 sub instrument($s) {
     $s->{instrument}
-        ? $s->_rh->equity_instruments_by_id( $s->{instrument}
-            =~ m'^.+/([0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12})/$'i )
+        ? $s->_rh->equity_instruments_by_id($s->{instrument}
+        =~ m'^.+/([0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12})/$'i
+        )
         : ();
 }
 
 sub _test_instrument {
     t::Utility::stash('MSFT') // skip_all();
-    isa_ok( t::Utility::stash('MSFT')->instrument, 'Finance::Robinhood::Equity::Instrument' );
+    isa_ok(t::Utility::stash('MSFT')->instrument,
+           'Finance::Robinhood::Equity::Instrument');
 }
 
 =head2 C<published_at( )>
@@ -173,12 +171,12 @@ Returns the time the article was published as a Time::Moment object.
 =cut
 
 sub published_at($s) {
-    Time::Moment->from_string( $s->{published_at} );
+    Time::Moment->from_string($s->{published_at});
 }
 
 sub _test_published_at {
     t::Utility::stash('MSFT') // skip_all();
-    isa_ok( t::Utility::stash('MSFT')->published_at, 'Time::Moment' );
+    isa_ok(t::Utility::stash('MSFT')->published_at, 'Time::Moment');
 }
 
 =head2 C<updated_at( )>
@@ -191,12 +189,12 @@ object.
 =cut
 
 sub updated_at($s) {
-    Time::Moment->from_string( $s->{updated_at} );
+    Time::Moment->from_string($s->{updated_at});
 }
 
 sub _test_updated_at {
     t::Utility::stash('MSFT') // skip_all();
-    isa_ok( t::Utility::stash('MSFT')->updated_at, 'Time::Moment' );
+    isa_ok(t::Utility::stash('MSFT')->updated_at, 'Time::Moment');
 }
 
 =head1 LEGAL
