@@ -19,7 +19,7 @@ Finance::Robinhood::Options::Chain - Represents a Single Options Chain
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
 use Time::Moment;
@@ -27,32 +27,30 @@ use Finance::Robinhood::Options::Chain::Ticks;
 use Finance::Robinhood::Options::Chain::Underlying;
 
 sub _test__init {
-    my $rh = t::Utility::rh_instance(0);
-
+    my $rh     = t::Utility::rh_instance(0);
     my $chains = $rh->options_chains;
     my $chain;
-    while ( $chains->has_next ) {
+    while ($chains->has_next) {
         my @dates = $chains->next->expiration_dates;
         if (@dates) {
             $chain = $chains->current;
             last;
         }
     }
-
-    isa_ok( $chain, __PACKAGE__ );
-    t::Utility::stash( 'CHAIN', $chain );    #  Store it for later
+    isa_ok($chain, __PACKAGE__);
+    t::Utility::stash('CHAIN', $chain);    #  Store it for later
 }
-use overload '""' => sub ( $s, @ ) { 'https://api.robinhood.com/options/chains/' . $s->{id} . '/' },
-    fallback      => 1;
+use overload '""' => sub ($s, @) {
+    'https://api.robinhood.com/options/chains/' . $s->{id} . '/';
+    },
+    fallback => 1;
 
 sub _test_stringify {
     t::Utility::stash('CHAIN') // skip_all();
-    like(
-        +t::Utility::stash('CHAIN'),
-        qr'^https://api.robinhood.com/options/chains/[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}/$'i
+    like(+t::Utility::stash('CHAIN'),
+         qr'^https://api.robinhood.com/options/chains/[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}/$'i
     );
 }
-
 has _rh => undef => weak => 1;
 
 =head2 C<can_open_position( )>
@@ -77,7 +75,10 @@ Chain's ticker symbol.
 
 =cut
 
-has [ 'can_open_position', 'cash_component', 'id', 'symbol', 'trade_value_multiplier' ];
+has ['can_open_position', 'cash_component',
+     'id',                'symbol',
+     'trade_value_multiplier'
+];
 
 =head2 C<expiration_dates( )>
 
@@ -86,13 +87,14 @@ Returns a list of Time::Moment objects.
 =cut
 
 sub expiration_dates($s) {
-    map { Time::Moment->from_string( $_ . 'T00:00:00Z' ) } @{ $s->{expiration_dates} };
+    map { Time::Moment->from_string($_ . 'T00:00:00Z') }
+        @{$s->{expiration_dates}};
 }
 
 sub _test_expiration_dates {
     t::Utility::stash('CHAIN') // skip_all();
     my ($date) = t::Utility::stash('CHAIN')->expiration_dates;
-    isa_ok( $date, 'Time::Moment' );
+    isa_ok($date, 'Time::Moment');
 }
 
 =head2 C<underlying_instruments( )>
@@ -102,17 +104,16 @@ Returns a list of Finance::Robinhood::Options::Chain::Underlying objects.
 =cut
 
 sub underlying_instruments($s) {
-    map { Finance::Robinhood::Options::Chain::Underlying->new( _rh => $s->_rh, %$_ ) }
-        @{ $s->{underlying_instruments} };
+    map {
+        Finance::Robinhood::Options::Chain::Underlying->new(_rh => $s->_rh,
+                                                            %$_)
+    } @{$s->{underlying_instruments}};
 }
 
 sub _test_underlying_instruments {
     t::Utility::stash('CHAIN') // skip_all();
     my ($underlying) = t::Utility::stash('CHAIN')->underlying_instruments;
-    isa_ok(
-        $underlying,
-        'Finance::Robinhood::Options::Chain::Underlying'
-    );
+    isa_ok($underlying, 'Finance::Robinhood::Options::Chain::Underlying');
 }
 
 =head2 C<min_ticks( )>
@@ -122,12 +123,14 @@ Returns a Finance::Robinhood::Options::Chain::Ticks object.
 =cut
 
 sub min_ticks ($s) {
-    Finance::Robinhood::Options::Chain::Ticks->new( _rh => $s->_rh, %{ $s->{min_ticks} } );
+    Finance::Robinhood::Options::Chain::Ticks->new(_rh => $s->_rh,
+                                                   %{$s->{min_ticks}});
 }
 
 sub _test_min_ticks {
     t::Utility::stash('CHAIN') // skip_all();
-    isa_ok( t::Utility::stash('CHAIN')->min_ticks, 'Finance::Robinhood::Options::Chain::Ticks' );
+    isa_ok(t::Utility::stash('CHAIN')->min_ticks,
+           'Finance::Robinhood::Options::Chain::Ticks');
 }
 
 =head1 LEGAL
