@@ -19,38 +19,37 @@ Chain's Underlying Equity Instrument
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
 
 sub _test__init {
     my $rh = t::Utility::rh_instance(1);
 
-    #my $instrument = $rh->options_instruments(
-    #    chain_id    => $rh->search('MSFT')->equity_instruments->[0]->tradable_chain_id,
-    #    tradability => 'tradable'
-    #)->current;
-    #isa_ok( $instrument, __PACKAGE__ );
-    #t::Utility::stash( 'INSTRUMENT', $instrument );    #  Store it for later
-    todo( "Write actual tests!" => sub { pass('ugh') } );
+#my $instrument = $rh->options_instruments(
+#    chain_id    => $rh->search('MSFT')->equity_instruments->[0]->tradable_chain_id,
+#    tradability => 'tradable'
+#)->current;
+#isa_ok( $instrument, __PACKAGE__ );
+#t::Utility::stash( 'INSTRUMENT', $instrument );    #  Store it for later
+    todo("Write actual tests!" => sub { pass('ugh') });
 }
-use overload '""' => sub ( $s, @ ) { $s->{instrument} }, fallback => 1;
+use overload '""' => sub ($s, @) { $s->{instrument} }, fallback => 1;
 
 sub _test_stringify {
     t::Utility::stash('UNDERLYING') // skip_all();
-    like(
-        +t::Utility::stash('UNDERLYING'),
-        qr'^https://api.robinhood.com/instruments/[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}/$'i
+    like(+t::Utility::stash('UNDERLYING'),
+         qr'^https://api.robinhood.com/instruments/[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}/$'i
     );
 }
 #
 has _rh => undef => weak => 1;
-has [ 'id', 'quantity' ];
+has ['id', 'quantity'];
 
 sub instrument($s) {
     Finance::Robinhood::Equity::Instrument->new(
-        _rh => $s->_rh,
-        %{ $s->_rh->_get( $s->{instrument} )->json }
+                                      _rh => $s->_rh,
+                                      %{$s->_rh->_get($s->{instrument})->json}
     );
 }
 
