@@ -13,34 +13,29 @@ Finance::Robinhood::Search - Represents Search Results
     use Text::Wrap qw[wrap];
     use Finance::Robinhood;
     my $rh = Finance::Robinhood->new;
-    
-    my $search = $rh->search('shoes');
 
+    my $search = $rh->search('shoes');
 
 =head1 METHODS
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 
 sub _test__init {
     my $rh   = t::Utility::rh_instance(1);
     my $msft = $rh->search('microsoft');
     my $btc  = $rh->search('bitcoin');
     my $tag  = $rh->search('New on Robinhood');
-
-    isa_ok( $msft, __PACKAGE__ );
-    t::Utility::stash( 'MSFT', $msft );    #  Store it for later
-
-    isa_ok( $btc, __PACKAGE__ );
-    t::Utility::stash( 'BTC', $btc );      #  Store it for later
-
-    isa_ok( $tag, __PACKAGE__ );
-    t::Utility::stash( 'TAG', $tag );      #  Store it for later
+    isa_ok($msft, __PACKAGE__);
+    t::Utility::stash('MSFT', $msft);    #  Store it for later
+    isa_ok($btc, __PACKAGE__);
+    t::Utility::stash('BTC', $btc);      #  Store it for later
+    isa_ok($tag, __PACKAGE__);
+    t::Utility::stash('TAG', $tag);      #  Store it for later
 }
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
-
 use Finance::Robinhood::Equity::Tag;
 use Finance::Robinhood::Forex::Pair;
 use Finance::Robinhood::Equity::Instrument;
@@ -55,13 +50,14 @@ objects.
 =cut
 
 sub forex_pairs ( $s ) {
-    map { Finance::Robinhood::Forex::Pair->new( _rh => $s->_rh, %$_ ) } @{ $s->{currency_pairs} };
+    map { Finance::Robinhood::Forex::Pair->new(_rh => $s->_rh, %$_) }
+        @{$s->{currency_pairs}};
 }
 
 sub _test_forex_pairs {
     t::Utility::stash('BTC') // skip_all();
     my ($btc_usd) = t::Utility::stash('BTC')->forex_pairs;
-    isa_ok( $btc_usd, 'Finance::Robinhood::Forex::Pair' );
+    isa_ok($btc_usd, 'Finance::Robinhood::Forex::Pair');
 }
 
 =head2 C<equity_instruments( )>
@@ -72,17 +68,14 @@ objects.
 =cut
 
 sub equity_instruments ( $s ) {
-    map { Finance::Robinhood::Equity::Instrument->new( _rh => $s->_rh, %$_ ) }
-        @{ $s->{instruments} };
+    map { Finance::Robinhood::Equity::Instrument->new(_rh => $s->_rh, %$_) }
+        @{$s->{instruments}};
 }
 
 sub _test_equity_instruments {
     t::Utility::stash('MSFT') // skip_all();
     my ($instrument) = t::Utility::stash('MSFT')->equity_instruments;
-    isa_ok(
-        $instrument,
-        'Finance::Robinhood::Equity::Instrument'
-    );
+    isa_ok($instrument, 'Finance::Robinhood::Equity::Instrument');
 }
 
 =head2 C<tags( )>
@@ -94,13 +87,14 @@ objects.
 =cut
 
 sub tags ( $s ) {
-    map { Finance::Robinhood::Equity::Tag->new( _rh => $s->_rh, %$_ ) } @{ $s->{tags} };
+    map { Finance::Robinhood::Equity::Tag->new(_rh => $s->_rh, %$_) }
+        @{$s->{tags}};
 }
 
 sub _test_tags {
     t::Utility::stash('TAG') // skip_all();
     my ($tag) = t::Utility::stash('TAG')->tags;
-    isa_ok( $tag, 'Finance::Robinhood::Equity::Tag' );
+    isa_ok($tag, 'Finance::Robinhood::Equity::Tag');
 }
 
 =head1 LEGAL
