@@ -18,13 +18,13 @@ Finance::Robinhood::User - Represents a Single Authorized User
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 
 sub _test__init {
     my $rh   = t::Utility::rh_instance(1);
     my $user = $rh->user;
-    isa_ok( $user, __PACKAGE__ );
-    t::Utility::stash( 'USER', $user );    #  Store it for later
+    isa_ok($user, __PACKAGE__);
+    t::Utility::stash('USER', $user);    #  Store it for later
 }
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
@@ -67,7 +67,7 @@ The username used to log in to the account.
 
 =cut
 
-has [ 'email', 'email_verified', 'first_name', 'last_name', 'id', 'username' ];
+has ['email', 'email_verified', 'first_name', 'last_name', 'id', 'username'];
 
 =head2 C<additional_info( )>
 
@@ -78,20 +78,18 @@ Returns a Finance::Robinhood::User::AdditionalInfo object.
 =cut
 
 sub additional_info($s) {
-    my $res = $s->_rh->_get( $s->{additional_info} );
-    $_[0]
-        = $res->is_success
-        ? Finance::Robinhood::User::AdditionalInfo->new( _rh => $s->_rh, %{ $res->json } )
+    my $res = $s->_rh->_get($s->{additional_info});
+    $_[0] = $res->is_success
+        ? Finance::Robinhood::User::AdditionalInfo->new(_rh => $s->_rh,
+                                                        %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_additional_info {
     t::Utility::stash('USER') // skip_all('No user object in stash');
-    isa_ok(
-        t::Utility::stash('USER')->additional_info,
-        'Finance::Robinhood::User::AdditionalInfo'
-    );
+    isa_ok(t::Utility::stash('USER')->additional_info,
+           'Finance::Robinhood::User::AdditionalInfo');
 }
 
 =head2 C<basic_info( )>
@@ -103,17 +101,18 @@ Returns a Finance::Robinhood::User::BasicInfo object.
 =cut
 
 sub basic_info($s) {
-    my $res = $s->_rh->_get( $s->{basic_info} );
-    $_[0]
-        = $res->is_success
-        ? Finance::Robinhood::User::BasicInfo->new( _rh => $s->_rh, %{ $res->json } )
+    my $res = $s->_rh->_get($s->{basic_info});
+    $_[0] = $res->is_success
+        ? Finance::Robinhood::User::BasicInfo->new(_rh => $s->_rh,
+                                                   %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_basic_info {
     t::Utility::stash('USER') // skip_all('No user object in stash');
-    isa_ok( t::Utility::stash('USER')->basic_info, 'Finance::Robinhood::User::BasicInfo' );
+    isa_ok(t::Utility::stash('USER')->basic_info,
+           'Finance::Robinhood::User::BasicInfo');
 }
 
 =head2 C<created_at( )>
@@ -125,12 +124,12 @@ Returns a Time::Moment object.
 =cut
 
 sub created_at ($s) {
-    Time::Moment->from_string( $s->{created_at} );
+    Time::Moment->from_string($s->{created_at});
 }
 
 sub _test_created_at {
     t::Utility::stash('USER') // skip_all();
-    isa_ok( t::Utility::stash('USER')->created_at(), 'Time::Moment' );
+    isa_ok(t::Utility::stash('USER')->created_at(), 'Time::Moment');
 }
 
 =head2 C<employment( )>
@@ -142,17 +141,18 @@ Returns a Finance::Robinhood::User::Employment object.
 =cut
 
 sub employment($s) {
-    my $res = $s->_rh->_get( $s->{employment} );
-    $_[0]
-        = $res->is_success
-        ? Finance::Robinhood::User::Employment->new( _rh => $s->_rh, %{ $res->json } )
+    my $res = $s->_rh->_get($s->{employment});
+    $_[0] = $res->is_success
+        ? Finance::Robinhood::User::Employment->new(_rh => $s->_rh,
+                                                    %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_employment {
     t::Utility::stash('USER') // skip_all('No user object in stash');
-    isa_ok( t::Utility::stash('USER')->employment, 'Finance::Robinhood::User::Employment' );
+    isa_ok(t::Utility::stash('USER')->employment,
+           'Finance::Robinhood::User::Employment');
 }
 
 =head2 C<id_info( )>
@@ -164,17 +164,18 @@ Returns a Finance::Robinhood::User::IDInfo object.
 =cut
 
 sub id_info($s) {
-    my $res = $s->_rh->_get( $s->{id_info} );
+    my $res = $s->_rh->_get($s->{id_info});
     $_[0]
         = $res->is_success
-        ? Finance::Robinhood::User::IDInfo->new( _rh => $s->_rh, %{ $res->json } )
+        ? Finance::Robinhood::User::IDInfo->new(_rh => $s->_rh, %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_id_info {
     t::Utility::stash('USER') // skip_all('No user object in stash');
-    isa_ok( t::Utility::stash('USER')->id_info, 'Finance::Robinhood::User::IDInfo' );
+    isa_ok(t::Utility::stash('USER')->id_info,
+           'Finance::Robinhood::User::IDInfo');
 }
 
 =head2 C<international_info( )>
@@ -187,22 +188,20 @@ non-US citizen.
 =cut
 
 sub international_info($s) {
-    my $res = $s->_rh->_get( $s->{international_info} );
-    $_[0]
-        = $res->is_success
-        ? Finance::Robinhood::User::InternationalInfo->new( _rh => $s->_rh, %{ $res->json } )
+    my $res = $s->_rh->_get($s->{international_info});
+    $_[0] = $res->is_success
+        ? Finance::Robinhood::User::InternationalInfo->new(_rh => $s->_rh,
+                                                           %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_international_info {
     t::Utility::stash('USER') // skip_all('No user object in stash');
     todo(
         'As a US citizen, this will fail for me' => sub {
-            isa_ok(
-                t::Utility::stash('USER')->international_info,
-                'Finance::Robinhood::User::InternationalInfo'
-            );
+            isa_ok(t::Utility::stash('USER')->international_info,
+                   'Finance::Robinhood::User::InternationalInfo');
         }
     );
 }
@@ -216,19 +215,21 @@ Returns a Finance::Robinhood::User::Profile object.
 =cut
 
 sub profile($s) {
-    my $res = $s->_rh->_get( $s->{investment_profile} );
+    my $res = $s->_rh->_get($s->{investment_profile});
     $_[0]
         = $res->is_success
-        ? Finance::Robinhood::User::Profile->new( _rh => $s->_rh, %{ $res->json } )
+        ? Finance::Robinhood::User::Profile->new(_rh => $s->_rh,
+                                                 %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_profile {
     t::Utility::stash('USER') // skip_all('No user object in stash');
     todo(
         'As a US citizen, this will fail for me' => sub {
-            isa_ok( t::Utility::stash('USER')->profile, 'Finance::Robinhood::User::Profile' );
+            isa_ok(t::Utility::stash('USER')->profile,
+                   'Finance::Robinhood::User::Profile');
         }
     );
 }
