@@ -21,16 +21,16 @@ Current User
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 
 sub _test__init {
     my $rh   = t::Utility::rh_instance(1);
     my $user = $rh->user;
-    isa_ok( $user, 'Finance::Robinhood::User' );
-    t::Utility::stash( 'USER', $user );    #  Store it for later
+    isa_ok($user, 'Finance::Robinhood::User');
+    t::Utility::stash('USER', $user);    #  Store it for later
     my $add_info = $user->additional_info();
-    isa_ok( $add_info, __PACKAGE__ );
-    t::Utility::stash( 'USER_ADD_INFO', $add_info );
+    isa_ok($add_info, __PACKAGE__);
+    t::Utility::stash('USER_ADD_INFO', $add_info);
 }
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
@@ -99,13 +99,18 @@ from Robinhood Financial and Robinhood Crypto with sweep.
 
 =cut
 
-has [
-    'agreed_to_rhs',                         'agreed_to_rhs_margin',
-    'control_person',                        'control_person_security_symbol',
-    'object_to_disclosure',                  'security_affiliated_address',
-    'security_affiliated_employee',          'security_affiliated_firm_name',
-    'security_affiliated_firm_relationship', 'security_affiliated_person_name',
-    'stock_loan_consent_status',             'sweep_consent'
+has ['agreed_to_rhs',
+     'agreed_to_rhs_margin',
+     'control_person',
+     'control_person_security_symbol',
+     'object_to_disclosure',
+     'security_affiliated_address',
+     'security_affiliated_employee',
+     'security_affiliated_firm_name',
+     'security_affiliated_firm_relationship',
+     'security_affiliated_person_name',
+     'stock_loan_consent_status',
+     'sweep_consent'
 ];
 
 =head2 C<updated_at( )>
@@ -117,12 +122,12 @@ Returns a Time::Moment object.
 =cut
 
 sub updated_at ($s) {
-    Time::Moment->from_string( $s->{updated_at} );
+    Time::Moment->from_string($s->{updated_at});
 }
 
 sub _test_updated_at {
     t::Utility::stash('USER_ADD_INFO') // skip_all();
-    isa_ok( t::Utility::stash('USER_ADD_INFO')->updated_at(), 'Time::Moment' );
+    isa_ok(t::Utility::stash('USER_ADD_INFO')->updated_at(), 'Time::Moment');
 }
 
 =head2 C<user( )>
@@ -136,17 +141,19 @@ Use this if you think the status or some other info might have changed.
 =cut
 
 sub user($s) {
-    my $res = $s->_rh->_get( $s->{user} );
+    my $res = $s->_rh->_get($s->{user});
     $_[0]
         = $res->is_success
-        ? Finance::Robinhood::User->new( _rh => $s->_rh, %{ $res->json } )
+        ? Finance::Robinhood::User->new(_rh => $s->_rh, %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_user {
-    t::Utility::stash('USER_ADD_INFO') // skip_all('No additional user data object in stash');
-    isa_ok( t::Utility::stash('USER_ADD_INFO')->user(), 'Finance::Robinhood::User' );
+    t::Utility::stash('USER_ADD_INFO')
+        // skip_all('No additional user data object in stash');
+    isa_ok(t::Utility::stash('USER_ADD_INFO')->user(),
+           'Finance::Robinhood::User');
 }
 
 =head1 LEGAL
