@@ -20,16 +20,16 @@ Finance::Robinhood::User::BasicInfo - Access Basic Data About the Current User
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 
 sub _test__init {
     my $rh   = t::Utility::rh_instance(1);
     my $user = $rh->user;
-    isa_ok( $user, 'Finance::Robinhood::User' );
-    t::Utility::stash( 'USER', $user );    #  Store it for later
+    isa_ok($user, 'Finance::Robinhood::User');
+    t::Utility::stash('USER', $user);    #  Store it for later
     my $basic_info = $user->basic_info();
-    isa_ok( $basic_info, __PACKAGE__ );
-    t::Utility::stash( 'USER_BASIC_INFO', $basic_info );
+    isa_ok($basic_info, __PACKAGE__);
+    t::Utility::stash('USER_BASIC_INFO', $basic_info);
 }
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
@@ -63,12 +63,13 @@ Returns a Time::Moment object.
 =cut
 
 sub date_of_birth ($s) {
-    Time::Moment->from_string( $s->{date_of_birth} . 'T00:00:00Z' );
+    Time::Moment->from_string($s->{date_of_birth} . 'T00:00:00Z');
 }
 
 sub _test_date_of_birth {
     t::Utility::stash('USER_BASIC_INFO') // skip_all();
-    isa_ok( t::Utility::stash('USER_BASIC_INFO')->date_of_birth(), 'Time::Moment' );
+    isa_ok(t::Utility::stash('USER_BASIC_INFO')->date_of_birth(),
+           'Time::Moment');
 }
 
 =head2 C<marital_status( )>
@@ -102,10 +103,12 @@ Mailing address zip code.
 
 =cut
 
-has [
-    'address',        'citizenship',       'city',         'country_of_residence',
-    'marital_status', 'number_dependents', 'phone_number', 'signup_as_rhs',
-    'state',          'tax_id_ssn',        'zipcode'
+has ['address',        'citizenship',
+     'city',           'country_of_residence',
+     'marital_status', 'number_dependents',
+     'phone_number',   'signup_as_rhs',
+     'state',          'tax_id_ssn',
+     'zipcode'
 ];
 
 =head2 C<updated_at( )>
@@ -117,12 +120,13 @@ Returns a Time::Moment object.
 =cut
 
 sub updated_at ($s) {
-    Time::Moment->from_string( $s->{updated_at} );
+    Time::Moment->from_string($s->{updated_at});
 }
 
 sub _test_updated_at {
     t::Utility::stash('USER_BASIC_INFO') // skip_all();
-    isa_ok( t::Utility::stash('USER_BASIC_INFO')->updated_at(), 'Time::Moment' );
+    isa_ok(t::Utility::stash('USER_BASIC_INFO')->updated_at(),
+           'Time::Moment');
 }
 
 =head2 C<user( )>
@@ -136,17 +140,19 @@ Use this if you think the status or some other info might have changed.
 =cut
 
 sub user($s) {
-    my $res = $s->_rh->_get( $s->{user} );
+    my $res = $s->_rh->_get($s->{user});
     $_[0]
         = $res->is_success
-        ? Finance::Robinhood::User->new( _rh => $s->_rh, %{ $res->json } )
+        ? Finance::Robinhood::User->new(_rh => $s->_rh, %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_user {
-    t::Utility::stash('USER_BASIC_INFO') // skip_all('No additional user data object in stash');
-    isa_ok( t::Utility::stash('USER_BASIC_INFO')->user(), 'Finance::Robinhood::User' );
+    t::Utility::stash('USER_BASIC_INFO')
+        // skip_all('No additional user data object in stash');
+    isa_ok(t::Utility::stash('USER_BASIC_INFO')->user(),
+           'Finance::Robinhood::User');
 }
 
 =head1 LEGAL
