@@ -20,16 +20,16 @@ Finance::Robinhood::User::Employment - Access Basic Data About the Current User
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 
 sub _test__init {
     my $rh   = t::Utility::rh_instance(1);
     my $user = $rh->user;
-    isa_ok( $user, 'Finance::Robinhood::User' );
-    t::Utility::stash( 'USER', $user );    #  Store it for later
+    isa_ok($user, 'Finance::Robinhood::User');
+    t::Utility::stash('USER', $user);    #  Store it for later
     my $basic_info = $user->employment();
-    isa_ok( $basic_info, __PACKAGE__ );
-    t::Utility::stash( 'USER_EMPLOYMENT_INFO', $basic_info );
+    isa_ok($basic_info, __PACKAGE__);
+    t::Utility::stash('USER_EMPLOYMENT_INFO', $basic_info);
 }
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
@@ -74,9 +74,10 @@ Number of years. This value is static and must be updated by the user.
 
 =cut
 
-has [
-    'employer_address', 'employer_city',     'employer_name', 'employer_state',
-    'employer_zipcode', 'employment_status', 'occupation',    'years_employed'
+has ['employer_address', 'employer_city',
+     'employer_name',    'employer_state',
+     'employer_zipcode', 'employment_status',
+     'occupation',       'years_employed'
 ];
 
 =head2 C<updated_at( )>
@@ -88,12 +89,13 @@ Returns a Time::Moment object.
 =cut
 
 sub updated_at ($s) {
-    Time::Moment->from_string( $s->{updated_at} );
+    Time::Moment->from_string($s->{updated_at});
 }
 
 sub _test_updated_at {
     t::Utility::stash('USER_EMPLOYMENT_INFO') // skip_all();
-    isa_ok( t::Utility::stash('USER_EMPLOYMENT_INFO')->updated_at(), 'Time::Moment' );
+    isa_ok(t::Utility::stash('USER_EMPLOYMENT_INFO')->updated_at(),
+           'Time::Moment');
 }
 
 =head2 C<user( )>
@@ -107,18 +109,19 @@ Use this if you think the status or some other info might have changed.
 =cut
 
 sub user($s) {
-    my $res = $s->_rh->_get( $s->{user} );
+    my $res = $s->_rh->_get($s->{user});
     $_[0]
         = $res->is_success
-        ? Finance::Robinhood::User->new( _rh => $s->_rh, %{ $res->json } )
+        ? Finance::Robinhood::User->new(_rh => $s->_rh, %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_user {
     t::Utility::stash('USER_EMPLOYMENT_INFO')
         // skip_all('No additional user data object in stash');
-    isa_ok( t::Utility::stash('USER_EMPLOYMENT_INFO')->user(), 'Finance::Robinhood::User' );
+    isa_ok(t::Utility::stash('USER_EMPLOYMENT_INFO')->user(),
+           'Finance::Robinhood::User');
 }
 
 =head1 LEGAL
