@@ -21,16 +21,16 @@ User
 
 =cut
 
-our $VERSION = '0.92_002';
+our $VERSION = '0.92_003';
 
 sub _test__init {
     my $rh   = t::Utility::rh_instance(1);
     my $user = $rh->user;
-    isa_ok( $user, 'Finance::Robinhood::User' );
-    t::Utility::stash( 'USER', $user );    #  Store it for later
+    isa_ok($user, 'Finance::Robinhood::User');
+    t::Utility::stash('USER', $user);    #  Store it for later
     my $profile = $user->profile();
-    isa_ok( $profile, __PACKAGE__ );
-    t::Utility::stash( 'USER_INV_INFO', $profile );
+    isa_ok($profile, __PACKAGE__);
+    t::Utility::stash('USER_INV_INFO', $profile);
 }
 use Mojo::Base-base, -signatures;
 use Mojo::URL;
@@ -285,15 +285,14 @@ Returns a boolean value.
 
 =cut
 
-has [
-    'annual_income',                   'interested_in_options',
-    'investment_experience_collected', 'investment_experience_collected',
-    'investment_objective',            'liquid_net_worth',
-    'liquidity_needs',                 'option_trading_experience',
-    'professional_trader',             'risk_tolerance',
-    'source_of_funds',                 'suitability_verified',
-    'tax_bracket',                     'time_horizon',
-    'total_net_worth',                 'understand_option_spreads'
+has ['annual_income',                   'interested_in_options',
+     'investment_experience_collected', 'investment_experience_collected',
+     'investment_objective',            'liquid_net_worth',
+     'liquidity_needs',                 'option_trading_experience',
+     'professional_trader',             'risk_tolerance',
+     'source_of_funds',                 'suitability_verified',
+     'tax_bracket',                     'time_horizon',
+     'total_net_worth',                 'understand_option_spreads'
 ];
 
 =head2 C<updated_at( )>
@@ -305,12 +304,12 @@ Returns a Time::Moment object.
 =cut
 
 sub updated_at ($s) {
-    Time::Moment->from_string( $s->{updated_at} );
+    Time::Moment->from_string($s->{updated_at});
 }
 
 sub _test_updated_at {
     t::Utility::stash('USER_INV_INFO') // skip_all();
-    isa_ok( t::Utility::stash('USER_INV_INFO')->updated_at(), 'Time::Moment' );
+    isa_ok(t::Utility::stash('USER_INV_INFO')->updated_at(), 'Time::Moment');
 }
 
 =head2 C<user( )>
@@ -324,17 +323,19 @@ Use this if you think the status or some other info might have changed.
 =cut
 
 sub user($s) {
-    my $res = $s->_rh->_get( $s->{user} );
+    my $res = $s->_rh->_get($s->{user});
     $_[0]
         = $res->is_success
-        ? Finance::Robinhood::User->new( _rh => $s->_rh, %{ $res->json } )
+        ? Finance::Robinhood::User->new(_rh => $s->_rh, %{$res->json})
         : Finance::Robinhood::Error->new(
-        $res->is_server_error ? ( details => $res->message ) : $res->json );
+             $res->is_server_error ? (details => $res->message) : $res->json);
 }
 
 sub _test_user {
-    t::Utility::stash('USER_INV_INFO') // skip_all('No user id data object in stash');
-    isa_ok( t::Utility::stash('USER_INV_INFO')->user(), 'Finance::Robinhood::User' );
+    t::Utility::stash('USER_INV_INFO')
+        // skip_all('No user id data object in stash');
+    isa_ok(t::Utility::stash('USER_INV_INFO')->user(),
+           'Finance::Robinhood::User');
 }
 
 =head1 LEGAL
